# general-template
A general Python project template for MF-DAS

After initializing your project from this template I would advice to do the following:

* Enable GitHub Pages by going to Settings -> Pages and choosing to build Pages from workflows.
* Change the name of your package by checking out the project and doing `git mv src/project_name src/your_actual_project_name` where `your_actual_project_name` is the name you chose for your project. After that `git commit -am "change package name"` and `git push`.
* Change the project name and other information in the `pyproject.toml`.
